==> graphviz-2.22.2.tar.gz: graphviz-2.22.2/lib/common/ps_font_equiv.h <==
#define TIMES "Times Roman"
#define COURIER "Courier"
#define HELVETICA "Arial"
#define HELVETICA "Arial"
#define SYMBOL "Symbol"
#define PALATINO "Palatino Linotype"
{"AvantGarde-Book",		"URW Gothic L",		"book",		0,		0,		4 ,	"sans-Serif",	0,	0},
{"AvantGarde-BookOblique",	"URW Gothic L",		"book",		0,		"oblique",	5 ,	"sans-Serif",	0,	"italic"},
{"AvantGarde-Demi",		"URW Gothic L",		"demi",		0,		0,		6 ,	"sans-Serif",	"bold",	0},
{"AvantGarde-DemiOblique",	"URW Gothic L",		"demi",		0,		"oblique",	7 ,	"sans-Serif",	"bold",	"italic"},
{"Bookman-Demi",		"URW Bookman L",	"demi",		0,		0,		10,	"serif",	"bold",	0},
{"Bookman-DemiItalic",		"URW Bookman L",	"demi",		0,		"italic",	11,	"serif",	"bold",	"italic"},
{"Bookman-Light",		"URW Bookman L",	"light",	0,		0,		8 ,	"serif",	0,	0},
{"Bookman-LightItalic",		"URW Bookman L",	"light",	0,		"italic",	9 ,	"serif",	0,	"italic"},
{"Courier",			COURIER,		0,        	0,		0,		12,	"monospace",	0,	0},
{"Courier-Bold",		COURIER,		"bold",		0,		0,		14,	"monospace",	"bold",	0},
{"Courier-BoldOblique",		COURIER,		"bold",		0,		"oblique",	15,	"monospace",	"bold",	"italic"},
{"Courier-Oblique",		COURIER,		0,        	0,		"oblique",	13,	"monospace",	0,	"italic"},
{"Helvetica",			HELVETICA,		0,        	0,		0,		16,	"sans-Serif",	0,	0},
{"Helvetica-Bold",		HELVETICA,		"bold",		0,		0,		18,	"sans-Serif",	"bold",	0},
{"Helvetica-BoldOblique",	HELVETICA,		"bold",		0,		"oblique",	19,	"sans-Serif",	"bold",	"italic"},
{"Helvetica-Narrow",		HELVETICA,		0,        	"condensed",	0,		20,	"sans-Serif",	0,	0},
{"Helvetica-Narrow-Bold",	HELVETICA,		"bold",		"condensed",	0,		22,	"sans-Serif",	"bold",	0},
{"Helvetica-Narrow-BoldOblique",HELVETICA,		"bold",		"condensed",	"oblique",	23,	"sans-Serif",	"bold",	"italic"},
{"Helvetica-Narrow-Oblique",	HELVETICA,		0,        	"condensed",	"oblique",	21,	"sans-Serif",	0,	"italic"},
{"Helvetica-Oblique",		HELVETICA,		0,        	0,		"oblique",	17,	"sans-Serif",	0,	"italic"},
{"NewCenturySchlbk-Bold",	"Century Schoolbook L",	"bold",		0,		0,		26,	"serif",	"bold",	0},
{"NewCenturySchlbk-BoldItalic",	"Century Schoolbook L",	"bold",		0,		"italic",	27,	"serif",	"bold",	"italic"},
{"NewCenturySchlbk-Italic",	"Century Schoolbook L",	0,		0,		"italic",	25,	"serif",	0,	"italic"},
{"NewCenturySchlbk-Roman",	"Century Schoolbook L",	"roman",	0,		0,		24,	"serif",	0,	0},
{"Palatino-Bold",		PALATINO,		"bold",		0,		0,		30,	"serif",	"bold",	0},
{"Palatino-BoldItalic",		PALATINO,		"bold",		0,		"italic",	31,	"serif",	"bold",	"italic"},
{"Palatino-Italic",		PALATINO,		0,		0,		"italic",	29,	"serif",	0,	"italic"},
{"Palatino-Roman",		PALATINO,		"roman",	0,		0,		28,	"serif",	0,	0},
{"Symbol",			SYMBOL,			0,        	0,		0,		32,	"fantasy",	0,	0},
{"Times-Bold",			"Times",		"bold",		0,		0,		2 ,	"serif",	"bold",	0},
{"Times-BoldItalic",		"Times",		"bold",		0,		"italic",	3 ,	"serif",	"bold",	"italic"},
{"Times-Italic",		"Times",		0,        	0,		"italic",	1 ,	"serif",	0,	"italic"},
{"Times-Roman",			TIMES,			0,       	0,		0,		0 ,	"serif",	0,	0},
{"ZapfChancery-MediumItalic",	"URW Chancery L",	"medium",	0,		"italic",	33,	"serif",	0,	"italic"},
{"ZapfDingbats",		"Dingbats",		0,		0,		0,		34,	"fantasy",	0,	0},

==> graphviz_2.26.3.orig.tar.gz: graphviz-2.26.3/lib/common/ps_font_equiv.h <==
#ifdef DARWIN
#define TIMES "Times"
#elif defined(WIN32)
#define TIMES "Times New Roman"
#else
#define TIMES "Times Roman"
#endif
#define COURIER "Courier"
#define HELVETICA "Helvetica"
#define SYMBOL "Symbol"
#define PALATINO "Palatino Linotype"
{"AvantGarde-Book",		"URW Gothic L",		"book",		0,		0,		4 ,	"sans-Serif",	0,	0},
{"AvantGarde-BookOblique",	"URW Gothic L",		"book",		0,		"oblique",	5 ,	"sans-Serif",	0,	"italic"},
{"AvantGarde-Demi",		"URW Gothic L",		"demi",		0,		0,		6 ,	"sans-Serif",	"bold",	0},
{"AvantGarde-DemiOblique",	"URW Gothic L",		"demi",		0,		"oblique",	7 ,	"sans-Serif",	"bold",	"italic"},
{"Bookman-Demi",		"URW Bookman L",	"demi",		0,		0,		10,	"serif",	"bold",	0},
{"Bookman-DemiItalic",		"URW Bookman L",	"demi",		0,		"italic",	11,	"serif",	"bold",	"italic"},
{"Bookman-Light",		"URW Bookman L",	"light",	0,		0,		8 ,	"serif",	0,	0},
{"Bookman-LightItalic",		"URW Bookman L",	"light",	0,		"italic",	9 ,	"serif",	0,	"italic"},
{"Courier",			COURIER,		0,        	0,		0,		12,	"monospace",	0,	0},
{"Courier-Bold",		COURIER,		"bold",		0,		0,		14,	"monospace",	"bold",	0},
{"Courier-BoldOblique",		COURIER,		"bold",		0,		"oblique",	15,	"monospace",	"bold",	"italic"},
{"Courier-Oblique",		COURIER,		0,        	0,		"oblique",	13,	"monospace",	0,	"italic"},
{"Helvetica",			HELVETICA,		0,        	0,		0,		16,	"sans-Serif",	0,	0},
{"Helvetica-Bold",		HELVETICA,		"bold",		0,		0,		18,	"sans-Serif",	"bold",	0},
{"Helvetica-BoldOblique",	HELVETICA,		"bold",		0,		"oblique",	19,	"sans-Serif",	"bold",	"italic"},
{"Helvetica-Narrow",		HELVETICA,		0,        	"condensed",	0,		20,	"sans-Serif",	0,	0},
{"Helvetica-Narrow-Bold",	HELVETICA,		"bold",		"condensed",	0,		22,	"sans-Serif",	"bold",	0},
{"Helvetica-Narrow-BoldOblique",HELVETICA,		"bold",		"condensed",	"oblique",	23,	"sans-Serif",	"bold",	"italic"},
{"Helvetica-Narrow-Oblique",	HELVETICA,		0,        	"condensed",	"oblique",	21,	"sans-Serif",	0,	"italic"},
{"Helvetica-Oblique",		HELVETICA,		0,        	0,		"oblique",	17,	"sans-Serif",	0,	"italic"},
{"NewCenturySchlbk-Bold",	"Century Schoolbook L",	"bold",		0,		0,		26,	"serif",	"bold",	0},
{"NewCenturySchlbk-BoldItalic",	"Century Schoolbook L",	"bold",		0,		"italic",	27,	"serif",	"bold",	"italic"},
{"NewCenturySchlbk-Italic",	"Century Schoolbook L",	0,		0,		"italic",	25,	"serif",	0,	"italic"},
{"NewCenturySchlbk-Roman",	"Century Schoolbook L",	"roman",	0,		0,		24,	"serif",	0,	0},
{"Palatino-Bold",		PALATINO,		"bold",		0,		0,		30,	"serif",	"bold",	0},
{"Palatino-BoldItalic",		PALATINO,		"bold",		0,		"italic",	31,	"serif",	"bold",	"italic"},
{"Palatino-Italic",		PALATINO,		0,		0,		"italic",	29,	"serif",	0,	"italic"},
{"Palatino-Roman",		PALATINO,		"roman",	0,		0,		28,	"serif",	0,	0},
{"Symbol",			SYMBOL,			0,        	0,		0,		32,	"fantasy",	0,	0},
{"Times-Bold",			"Times",		"bold",		0,		0,		2 ,	"serif",	"bold",	0},
{"Times-BoldItalic",		"Times",		"bold",		0,		"italic",	3 ,	"serif",	"bold",	"italic"},
{"Times-Italic",		"Times",		0,        	0,		"italic",	1 ,	"serif",	0,	"italic"},
{"Times-Roman",			TIMES,			0,       	0,		0,		0 ,	"serif",	0,	0},
{"ZapfChancery-MediumItalic",	"URW Chancery L",	"medium",	0,		"italic",	33,	"serif",	0,	"italic"},
{"ZapfDingbats",		"Dingbats",		0,		0,		0,		34,	"fantasy",	0,	0},
